
.. DO NOT EDIT.
.. THIS FILE WAS AUTOMATICALLY GENERATED BY SPHINX-GALLERY.
.. TO MAKE CHANGES, EDIT THE SOURCE PYTHON FILE:
.. "generated/autoexamples/example_display_config.py"
.. LINE NUMBERS ARE GIVEN BELOW.

.. only:: html

    .. note::
        :class: sphx-glr-download-link-note

        :ref:`Go to the end <sphx_glr_download_generated_autoexamples_example_display_config.py>`
        to download the full example code. or to run this example in your browser via Binder

.. rst-class:: sphx-glr-example-title

.. _sphx_glr_generated_autoexamples_example_display_config.py:


================================
Trajectory display configuration
================================

An example to show how to customize trajectory displays.

The parameters presented here can be tuned to your own taste and needs
by using :py:class:`displayConfig`.

.. GENERATED FROM PYTHON SOURCE LINES 11-19

.. code-block:: Python


    import matplotlib as mpl
    import matplotlib.pyplot as plt
    import numpy as np

    from mrinufft import display_2D_trajectory, display_3D_trajectory, displayConfig
    from mrinufft.trajectories import conify, initialize_2D_spiral








.. GENERATED FROM PYTHON SOURCE LINES 20-23

Script options
==============
These options are used in the examples below to define trajectories and display options.

.. GENERATED FROM PYTHON SOURCE LINES 23-33

.. code-block:: Python


    # Trajectory parameters
    Nc = 120  # Number of shots
    Ns = 500  # Number of samples per shot

    # Display parameters
    figure_size = 10  # Figure size for trajectory plots
    subfigure_size = 6  # Figure size for subplots
    one_shot = -5  # Highlight one shot in particular








.. GENERATED FROM PYTHON SOURCE LINES 34-50

.. code-block:: Python



    def show_traj(traj, name, values, **kwargs):
        fig, axs = plt.subplots(
            1,
            len(values),
            figsize=(subfigure_size * len(values), subfigure_size),
            subplot_kw={"projection": "3d"},
        )
        for ax, val in zip(axs, values):
            with displayConfig(**{name: val}):
                display_3D_trajectory(traj, subfigure=ax, **kwargs)
                ax.set_title(f"{name}={val}", fontsize=2 * subfigure_size)
        plt.show()









.. GENERATED FROM PYTHON SOURCE LINES 51-57

Trajectory displays
===================

The following trajectory will be used to showcase the display parameters.
The trajectory parameters are explained in the
:ref:`sphx_glr_generated_autoexamples_example_3D_trajectories.py` example.

.. GENERATED FROM PYTHON SOURCE LINES 58-61

.. code-block:: Python


    traj = conify(initialize_2D_spiral(Nc // 6, Ns), nb_cones=6)[::-1]








.. GENERATED FROM PYTHON SOURCE LINES 62-66

``linewidth``
-------------
The ``linewidth`` corresponds to the curve thickness, and can be changed
to improve the shots visibility.

.. GENERATED FROM PYTHON SOURCE LINES 66-68

.. code-block:: Python

    show_traj(traj, "linewidth", [0.5, 2, 4])




.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_001.png
   :alt: linewidth=0.5, linewidth=2, linewidth=4
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_001.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 69-72

``palette``
-----------
The ``palette`` parameter allows you to change the color of the shots.

.. GENERATED FROM PYTHON SOURCE LINES 72-74

.. code-block:: Python

    show_traj(traj, "palette", ["tab10", "magma", "jet"])




.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_002.png
   :alt: palette=tab10, palette=magma, palette=jet
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_002.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 75-79

``one_shot_color``
------------------
The ``one_shot_color`` parameter is used to highlight one shot in particular
with a specified color.

.. GENERATED FROM PYTHON SOURCE LINES 79-84

.. code-block:: Python

    with displayConfig(palette="viridis"):
        show_traj(
            traj, "one_shot_color", ["tab:blue", "tab:orange", "tab:green"], one_shot=-5
        )




.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_003.png
   :alt: one_shot_color=tab:blue, one_shot_color=tab:orange, one_shot_color=tab:green
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_003.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 85-89

``nb_colors``
-------------
The ``nb_colors`` parameter allows you to change the number of colors used from the
specified color palette to display the shots.

.. GENERATED FROM PYTHON SOURCE LINES 89-92

.. code-block:: Python

    show_traj(traj, "nb_colors", [1, 4, 10])





.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_004.png
   :alt: nb_colors=1, nb_colors=4, nb_colors=10
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_004.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 93-95

Labels, titles and legends
==========================

.. GENERATED FROM PYTHON SOURCE LINES 97-100

``fontsize``
------------
The ``fontsize`` parameter changes the fontsize of the labels/titles.

.. GENERATED FROM PYTHON SOURCE LINES 100-102

.. code-block:: Python

    show_traj(traj, "fontsize", [12, 18, 24])




.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_005.png
   :alt: fontsize=12, fontsize=18, fontsize=24
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_005.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 103-107

``pointsize``
-------------
The ``pointsize`` parameter is used when showing the gradient constraint violations
to change the violation point sizes.

.. GENERATED FROM PYTHON SOURCE LINES 107-109

.. code-block:: Python

    show_traj(traj, "pointsize", [0.5, 2, 4], show_constraints=True)




.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_006.png
   :alt: pointsize=0.5, pointsize=2, pointsize=4
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_006.png
   :class: sphx-glr-single-img





.. GENERATED FROM PYTHON SOURCE LINES 110-115

``gradient_point_color`` and ``slewrate_point_color``
-----------------------------------------------------
The ``gradient_point_color`` and ``slewrate_point_color`` parameters allows you
to change the color of the points where gradient or slew rate constraint violations
are observed.

.. GENERATED FROM PYTHON SOURCE LINES 115-121

.. code-block:: Python

    show_traj(
        traj,
        "slewrate_point_color",
        ["tab:blue", "tab:orange", "tab:red"],
        show_constraints=True,
    )



.. image-sg:: /generated/autoexamples/images/sphx_glr_example_display_config_007.png
   :alt: slewrate_point_color=tab:blue, slewrate_point_color=tab:orange, slewrate_point_color=tab:red
   :srcset: /generated/autoexamples/images/sphx_glr_example_display_config_007.png
   :class: sphx-glr-single-img






.. rst-class:: sphx-glr-timing

   **Total running time of the script:** (0 minutes 5.185 seconds)


.. _sphx_glr_download_generated_autoexamples_example_display_config.py:

.. only:: html

  .. container:: sphx-glr-footer sphx-glr-footer-example

    .. container:: binder-badge

      .. image:: images/binder_badge_logo.svg
        :target: https://mybinder.org/v2/gh/mind-inria/mri-nufft/gh-pages?urlpath=lab/tree/examples/generated/autoexamples/example_display_config.ipynb
        :alt: Launch binder
        :width: 150 px

    .. container:: sphx-glr-download sphx-glr-download-jupyter

      :download:`Download Jupyter notebook: example_display_config.ipynb <example_display_config.ipynb>`

    .. container:: sphx-glr-download sphx-glr-download-python

      :download:`Download Python source code: example_display_config.py <example_display_config.py>`

    .. container:: sphx-glr-download sphx-glr-download-zip

      :download:`Download zipped: example_display_config.zip <example_display_config.zip>`


.. only:: html

 .. rst-class:: sphx-glr-signature

    `Gallery generated by Sphinx-Gallery <https://sphinx-gallery.github.io>`_
